Module blaxel.core.client.models.workspace_user
===============================================

Classes
-------

`WorkspaceUser(accepted: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, email: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, email_verified: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, family_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, given_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, role: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, sub: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Workspace user
    
    Attributes:
        accepted (Union[Unset, bool]): Whether the user has accepted the workspace invitation
        email (Union[Unset, str]): Workspace user email
        email_verified (Union[Unset, bool]): Whether the user's email has been verified
        family_name (Union[Unset, str]): Workspace user family name
        given_name (Union[Unset, str]): Workspace user given name
        role (Union[Unset, str]): Workspace user role
        sub (Union[Unset, str]): Workspace user identifier
    
    Method generated by attrs for class WorkspaceUser.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `accepted: blaxel.core.client.types.Unset | bool`
    :

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `email: blaxel.core.client.types.Unset | str`
    :

    `email_verified: blaxel.core.client.types.Unset | bool`
    :

    `family_name: blaxel.core.client.types.Unset | str`
    :

    `given_name: blaxel.core.client.types.Unset | str`
    :

    `role: blaxel.core.client.types.Unset | str`
    :

    `sub: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :